#! /bin/sh

# This script is part of CVS Utilities, version @VERSION@.
# This script discards local changes and non-CVS files, creating a clean
# working directory.

set -e

echo "cvsco: cleaning up ..."
cvsu --ignore --find --types '^.FCRUX' --batch "rm -rf" "$@"

echo "cvsco: refetching missing files ..."
cvsu --ignore --find --types 'U' --batch "cvs update" "$@"

echo "cvsco: done"
